/*
 * write_icao.c - functions to write ICAO Map format output
 *
 * Copyright (C) 1998, John C. Peterson <mailto:jaypee@netcom.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License,
 * version 2. A copy is included in this distribution in the file
 * named "LICENSE".
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License, version 2, for more details.
 *
 * $Id: write_icao.c,v 1.1 1998/05/05 06:43:46 jcp Exp $
 *
 */

#include <stdio.h>
#include <string.h>
#include <math.h>

#include "faaconv.h"

static char outbuf[BUF_LEN];

static bool_t write_icao_apt(char **tok_str);
static bool_t write_icao_fix(char **tok_str);
static bool_t write_icao_ils(char **tok_str);
static bool_t write_icao_nav(char **tok_str);
static bool_t write_icao_rwy(char **tok_str);

/* -------------------------------------------------------------------------- */

static bool_t write_icao_apt(char **tok_str)
{

  apt_t *rec = (void *) tok_str;

  char *p = outbuf;

  int nscan;
  int degrees;
  int minutes;
  double seconds;
  char lat_ns[2];
  char lon_ew[2];
  char *keyword;

  /* at keyword */

  SPRINTF(p,"%s ", "at");

  /* latitude */

  nscan = sscanf(rec->ref_point_latitude, "%d-%d-%lf%1[NS]",
                 &degrees, &minutes, &seconds, lat_ns);

  if (nscan == 4) {
    SPRINTF(p,"%02d.", degrees);
    SPRINTF(p,"%02d\'", minutes);
    SPRINTF(p,"%02d\"", (int) seconds);
    SPRINTF(p,"%c ", lat_ns[0]);
  } else {
    return FALSE;
  }

  /* longitude */

  nscan = sscanf(rec->ref_point_longitude, "%d-%d-%lf%1[EW]",
                 &degrees, &minutes, &seconds, lon_ew);

  if (nscan == 4) {
    if (fabs(degrees) < 100.0) {
      SPRINTF(p,"%02d.", degrees);
    } else {
      SPRINTF(p,"%d.", degrees);
    }
    SPRINTF(p,"%02d\'", minutes);
    SPRINTF(p,"%02d\"", (int) seconds);
    SPRINTF(p,"%c ", lon_ew[0]);
  } else {
    return FALSE;
  }

  /* airport elevation */

  SPRINTF(p,"elev %s\n", rec->airport_elevation);

  /* airport type */

  if (strcmp(rec->airport_type,"AIRPORT") == 0) {
    keyword = "airport";
  } else if (strcmp(rec->airport_type,"BALLOONPORT") == 0) {
    keyword = "free_balloon_site";
  } else if (strcmp(rec->airport_type,"GLIDERPORT") == 0) {
    keyword = "glider_site";
  } else if (strcmp(rec->airport_type,"HELIPORT") == 0) {
    keyword = "heliport";
  } else if (strcmp(rec->airport_type,"SEAPLANE BASE") == 0) {
    keyword = "airport";
  } else if (strcmp(rec->airport_type,"STOLPORT") == 0) {
    keyword = "airport";
  } else if (strcmp(rec->airport_type,"ULTRALIGHT") == 0) {
    keyword = "special_airfield";
  } else {
    /* huh? */
    return FALSE;
  }

  SPRINTF(p," %s ", keyword);

  /* airport name */

  SPRINTF(p,"\"%s\"\n", rec->airport_name);

  /* common traffic advisory frequency */

  if (rec->common_traffic_advisory_frequency[0] != '\0') {
    SPRINTF(p," freq %s\n", rec->common_traffic_advisory_frequency);
  }

  /* airport id */

  if (option_k) {
    rec->airport_id = strkid(rec->airport_id);
  }

  SPRINTF(p," alias \"%s\"\n", rec->airport_id);

  /* normal exit */

  *p = '\0';

  fprintf(fpoutput, "%s\n", outbuf);

  return TRUE;

}

/* -------------------------------------------------------------------------- */

static bool_t write_icao_fix(char **tok_str)
{

  return FALSE;

}

/* -------------------------------------------------------------------------- */

static bool_t write_icao_ils(char **tok_str)
{

  return FALSE;

}

/* -------------------------------------------------------------------------- */

static bool_t write_icao_nav(char **tok_str)
{

  return FALSE;

}

/* -------------------------------------------------------------------------- */

static bool_t write_icao_rwy(char **tok_str)
{

  return FALSE;

}

/* -------------------------------------------------------------------------- */

bool_t write_icao(char **tok_str)
{

  bool_t rc = FALSE;

  switch (db_type) {

    case DB_APT:
      rc = write_icao_apt(tok_str);
      break;

    case DB_FIX:
      rc = write_icao_fix(tok_str);
      break;

    case DB_ILS:
      rc = write_icao_ils(tok_str);
      break;

    case DB_NAV:
      rc = write_icao_nav(tok_str);
      break;

    case DB_RWY:
      rc = write_icao_rwy(tok_str);
      break;

  }

  /* return result */

  return rc;

}

/* -------------------------------------------------------------------------- */

